/*******************************************************************************
 * Copyright (c) 2016 ALL4TEC & CEA LIST.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     ALL4TEC & CEA LIST - initial API and implementation
 ******************************************************************************/
package org.polarsys.esf.localanalysis.execution.util;

import org.eclipse.emf.transaction.RecordingCommand;
import org.eclipse.emf.transaction.TransactionalEditingDomain;
import org.eclipse.uml2.uml.Package;
import org.eclipse.uml2.uml.util.UMLUtil;
import org.polarsys.esf.core.utils.ModelUtil;
import org.polarsys.esf.esflocalanalysis.impl.ESFLocalAnalysisPackage;

/**
 * Utilities for working with SSystemEvents.
 *
 * @author $Author: ymunoz $
 * @version $Revision: 168 $
 */
public final class SSystemEventsUtil {

    /** System Events Library name. */
    public static final String SYSTEM_EVENTS_LIBRARY_NAME = "SystemEventsLibrary"; //$NON-NLS-1$

    /** Create System Events Library label. */
    public static final String CREATE_SYSTEM_EVENTS_LIBRARY_LABEL = "Create SystemEventsLibrary"; //$NON-NLS-1$

    /**
     * Default constructor.
     */
    private SSystemEventsUtil() {
    }

    /**
     * Create the System Events Library.
     *
     * @param pLocalAnalysis The LocalAnalysis package where the library must be created
     */
    public static void createSSystemEventsLibrary(final Package pLocalAnalysis) {
        TransactionalEditingDomain vDomain = ModelUtil.getTransactionalEditingDomain(pLocalAnalysis);

        RecordingCommand vCreateSystemEventsLibrary =
            new RecordingCommand(vDomain, CREATE_SYSTEM_EVENTS_LIBRARY_LABEL) {

                @Override
                protected void doExecute() {
                    // Create the object 'SystemEventsLibrary' package
                    Package vSSystemEventsLibrary = pLocalAnalysis.createNestedPackage(SYSTEM_EVENTS_LIBRARY_NAME);
                    // Apply 'SSystemEventsLibrary' stereotype on 'SystemEventsLibrary' package
                    UMLUtil.StereotypeApplicationHelper.getInstance(vSSystemEventsLibrary).applyStereotype(
                        vSSystemEventsLibrary,
                        ESFLocalAnalysisPackage.eINSTANCE.getSSystemEventsLibrary());
                }
            };

        // Verify if command can be executed
        if (vCreateSystemEventsLibrary.canExecute()) {
            // Execute command
            vDomain.getCommandStack().execute(vCreateSystemEventsLibrary);
        }
    }
}
